==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/km-KH/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'អង់គ្លេស អាមេរិក',
        'en-GB'=> 'ភាសាអង់គ្លេស ចក្រភពអង់គ្លេស',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'អាហ្រ្វិក',
        'ar-SA'=> 'ភាសាអារ៉ាប់',
        'bg-BG'=> 'ប៊ុលហ្គារី',
        'zh-CN'=> 'ភាសាចិនសាមញ្ញ',
        'zh-TW'=> 'ភាសា​ចិន ប្រពៃណី',
        'ca-ES' => 'Catalan',
        'hr-HR'=> 'ក្រូអាត',
        'cs-CZ'=> 'ឆេក',
        'da-DK'=> 'ដាណឺម៉ាក',
        'nl-NL'=> 'ហូឡង់',
        'en-ID'=> 'អង់គ្លេស ឥណ្ឌូនេស៊ី',
        'et-EE'=> 'អេស្តូនី',
        'fil-PH'=> 'ហ្វីលីពីន',
        'fi-FI'=> 'ហ្វាំងឡង់',
        'fr-FR'=> 'បារាំង',
        'de-DE'=> 'អាឡឺម៉ង់',
        'de-if'=> 'អាល្លឺម៉ង់ (មិនផ្លូវការ)',
        'el-GR'=> 'ក្រិក',
        'he-IL'=> 'ភាសាហេព្រើរ',
        'hu-HU'=> 'ហុងគ្រី',
        'is-IS' => 'អ៊ីស្លង់',
        'id-ID'=> 'ឥណ្ឌូនេស៊ី',
        'ga-IE'=> 'អៀរឡង់',
        'it-IT'=> 'អ៊ីតាលី',
        'ja-JP'=> 'ជប៉ុន',
        'km-KH'=>'ខ្មែរ',
        'ko-KR'=> 'កូរ៉េ',
        'lt-LT'=>'លីទុយអានី',
        'lv-LV'=> 'ឡាតវី',
        'mk-MK'=> 'ម៉ាសេដូនៀ',
        'ms-MY'=> 'ម៉ាឡេ',
        'mi-NZ'=> 'ម៉ៅរី',
        'mn-MN'=> 'ម៉ុងហ្គោលី',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'ពែរ្ស',
        'pl-PL'=> 'ប៉ូឡូញ',
        'pt-PT'=> 'ព័រទុយហ្គាល់',
        'pt-BR'=> 'ព័រទុយហ្គាល់ ប្រេស៊ីល',
        'ro-RO'=> 'រ៉ូម៉ានី',
        'ru-RU'=> 'រុស្សី',
        'sr-CS' => 'ស៊ែប៊ី (ឡាតាំង)',
        'sk-SK'=> 'Slovak',
        'sl-SI'=> 'ស្លូវេនី',
        'so-SO'=> 'Somali',
        'es-ES'=> 'ភាសាអេស្ប៉ាញ',
        'es-CO'=> 'អេស្ប៉ាញ កូឡុំប៊ី',
        'es-MX'=> 'អេស្ប៉ាញ ម៉ិកស៊ិក',
        'es-VE'=> 'អេស្ប៉ាញ វេណេស៊ុយអេឡា',
        'sv-SE'=> 'ស៊ុយអែត',
        'tl-PH'=> 'តាកាឡុក',
        'ta-IN'=> 'តាមីល',
        'th-TH'=> 'ថៃ',
        'tr-TR'=> 'ទួរគី',
        'uk-UA'=> 'អ៊ុយក្រែន',
        'vi-VN'=> 'វៀតណាម',
        'cy-GB'=> 'វែល',
        'zu-ZA'=> 'ហ្សូលូ',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'កោះ Ascension',
        'AD'=>'អង់ដូរ៉ា',
        'AE'=>'សហព័ន្ធ​អារ៉ាប់រួម',
        'AF'=>'អាហ្វហ្គានីស្ថាន',
        'AG'=>'Antigua និង Barbuda',
        'AI'=>'អង់ហ្គីឡា',
        'AL'=>'អាល់បានី',
        'AM'=>'អាមេនី',
        'AN'=>'ហូឡង់ Antilles',
        'AO'=>'អង់ហ្គោឡា',
        'AQ'=>'អង់តាក់ទិក',
        'AR'=>'អាហ្សង់ទីន',
        'AS'=>'សាម័រអាមេរិក',
        'AT'=>'អូទ្រីស',
        'AU'=>'អូស្ត្រាលី',
        'AW'=>'អារូបា',
        'AX'=>'Ãƒâ€¦land',
        'AZ'=>'អាស៊ែបៃហ្សង់',
        'BA'=>'បូស្នៀ និងហឺហ្សេហ្គោវីណា',
        'BB'=>'បាបាដូស',
        'BE'=>'បែលហ្សិក',
        'BD'=>'បង់ក្លាដែស',
        'BF'=>'ប៊ូគីណាហ្វាសូ',
        'BG'=>'ប៊ុលហ្គារី',
        'BH'=>'បារ៉ែន',
        'BI'=>'ប៊ូរុនឌី',
        'BJ'=>'បេនីន',
        'BM'=>'ប៊ឺមូដា',
        'BN'=>'ប្រទេស​ព្រុយ​ណេ​ដា​រូ​សា​ឡឹម',
        'BO'=>'បូលីវី',
        'BR'=>'ប្រេស៊ីល',
        'BS'=>'បាហាម៉ាស',
        'BT'=>'ប៊ូតាន',
        'BV'=>'កោះប៊ូវេ',
        'BW'=>'បូតស្វាណា',
        'BY'=>'បេឡារុស្ស',
        'BZ'=>'បេលីស',
        'CA'=>'ប្រទេសកាណាដា',
        'CC'=>'កោះ Cocos (Keeling)',
        'CD'=>'កុងហ្គោ (សាធារណរដ្ឋប្រជាធិបតេយ្យ)',
        'CF'=>'សាធារណរដ្ឋអាហ្វ្រិកកណ្តាល',
        'CG'=>'កុងហ្គោ (សាធារណរដ្ឋ)',
        'CH'=>'ប្រទេស​ស្វីស',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Cook Islands',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'People\'s Republic of China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Cyprus',
        'CZ'=>'Czech Republic',
        'DE'=>'Germany',
        'DJ'=>'Djibouti',
        'DK'=>'Denmark',
        'DM'=>'Dominica',
        'DO'=>'Dominican Republic',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egypt',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Spain',
        'ET'=>'Ethiopia',
        'EU'=>'European Union',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Islands (Malvinas)',
        'FM'=>'Micronesia, Federated States Of',
        'FO'=>'Faroe Islands',
        'FR'=>'France',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'French Guiana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Greece',
        'GS'=>'South Georgia And The South Sandwich Islands',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'ហុងកុង',
        'HM'=>'កោះ Heard និង Mcdonald',
        'HN'=>'ហុងឌូរ៉ាស',
        'HR'=>'ក្រូអាត (ឈ្មោះក្នុងស្រុក៖ Hrvatska)',
        'HT'=>'ហៃទី',
        'HU'=>'ហុងគ្រី',
        'ID'=>'ប្រទេសឥណ្ឌូនេស៊ី',
        'IE'=>'អៀរឡង់',
        'IL'=>'អ៊ីស្រាអែល',
        'IM'=>'កោះម៉ាន់',
        'IN'=>'ប្រទេសឥណ្ឌា',
        'IO'=>'ដែនដីមហាសមុទ្រឥណ្ឌាអង់គ្លេស',
        'IQ'=>'អ៊ីរ៉ាក់',
        'IR'=>'អ៊ីរ៉ង់ សាធារណរដ្ឋអ៊ីស្លាម',
        'IS'=>'អ៊ីស្លង់',
        'IT'=>'ប្រទេសអ៊ីតាលី',
        'JE'=>'ជឺស៊ី',
        'JM'=>'ចាម៉ៃកា',
        'JO'=>'ហ្ស៊កដានី',
        'JP'=>'ហ្ស៊កដានី',
        'KE'=>'កេនយ៉ា',
        'KG'=>'កៀហ្ស៊ីស៊ីស្ថាន',
        'KH'=>'កម្ពុជា',
        'KI'=>'គីរីបាទី',
        'KM'=>'កូម៉ូរ៉ូ',
        'KN'=>'Saint Kitts And Nevis',
        'KR'=>'កូរ៉េ សាធារណរដ្ឋ',
        'KW'=>'គុយវ៉ែត',
        'KY'=>'កោះកៃម៉ាន',
        'KZ'=>'កាហ្សាក់ស្ថាន',
        'LA'=>'សាធារណរដ្ឋប្រជាធិបតេយ្យប្រជាមានិតឡាវ',
        'LB'=>'លីបង់',
        'LC'=>'សាំងលូសៀ',
        'LI'=>'លីចតេនស្ទីន',
        'LK'=>'ស្រី​លង្កា',
        'LR'=>'លីបេរីយ៉ា',
        'LS'=>'ឡេសូតូ',
        'LT'=>'លីទុយអានី',
        'LU'=>'លុចសំបួរ',
        'LV'=>'ឡាតវី',
        'LY'=>'លីប៊ី អារ៉ាប់ ចាម៉ាហ៊ីរីយ៉ា',
        'MA'=>'ម៉ារ៉ុក',
        'MC'=>'ម៉ូណាកូ',
        'MD'=>'ម៉ុលដាវី សាធារណរដ្ឋ',
        'ME'=>'ម៉ុងតេណេហ្គ្រោ',
        'MG'=>'ម៉ាដាហ្គាស្ការ',
        'MH'=>'កោះម៉ាស្យែល',
        'MK'=>'ម៉ាសេដូនៀ អតីតសាធារណរដ្ឋយូហ្គោស្លាវី',
        'ML'=>'ប្រទេសម៉ាលី',
        'MM'=>'មីយ៉ាន់ម៉ា',
        'MN'=>'Mongolia',
        'MO'=>'Macau',
        'MP'=>'Northern Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolk Island',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Netherlands',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'French Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Philippines, Republic of the',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre And Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russian Federation',
        'RW'=>'Rwanda',
        'SA'=>'Saudi Arabia',
        'GB-SCT'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'សីស្ហែល',
        'SS'=>'South Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sweden',
        'SG'=>'Singapore',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard And Jan Mayen Islands',
        'SK'=>'Slovakia (Slovak Republic)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome And Principe',
        'SU'=>'Soviet Union',
        'SV'=>'El Salvador',
        'SY'=>'Syrian Arab Republic',
        'SZ'=>'Swaziland',
        'TC'=>'Turks And Caicos Islands',
        'TD'=>'Chad',
        'TF'=>'French Southern Territories',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'East Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (old code)',
        'TR'=>'Turkey',
        'TT'=>'Trinidad And Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, United Republic Of',
        'UA'=>'Ukraine',
        'UG'=>'Uganda',
        'UK'=>'United Kingdom',
        'US'=>'United States',
        'UM'=>'United States Minor Outlying Islands',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatican City State (Holy See)',
        'VC'=>'Saint Vincent And The Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Islands (British)',
        'VI'=>'Virgin Islands (U.S.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis And Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/km-KH/localizations.php <==
<?php

return [

    'select_language' => 'ជ្រើសរើសភាសា',
    'languages' => [
        'en-US'=> 'អង់គ្លេស អាមេរិក',
        'en-GB'=> 'ភាសាអង់គ្លេស ចក្រភពអង់គ្លេស',
        'am-ET' => 'អាំហារិក',
        'af-ZA'=> 'អាហ្រ្វិក',
        'ar-SA'=> 'ភាសាអារ៉ាប់',
        'bg-BG'=> 'ប៊ុលហ្គារី',
        'zh-CN'=> 'ភាសាចិនសាមញ្ញ',
        'zh-TW'=> 'ភាសា​ចិន ប្រពៃណី',
        'ca-ES' => 'កាតាឡាន',
        'hr-HR'=> 'ក្រូអាត',
        'cs-CZ'=> 'ឆេក',
        'da-DK'=> 'ដាណឺម៉ាក',
        'nl-NL'=> 'ហូឡង់',
        'en-ID'=> 'អង់គ្លេស ឥណ្ឌូនេស៊ី',
        'et-EE'=> 'អេស្តូនី',
        'fil-PH'=> 'ហ្វីលីពីន',
        'fi-FI'=> 'ហ្វាំងឡង់',
        'fr-FR'=> 'បារាំង',
        'de-DE'=> 'អាឡឺម៉ង់',
        'de-if'=> 'អាល្លឺម៉ង់ (មិនផ្លូវការ)',
        'el-GR'=> 'ក្រិក',
        'he-IL'=> 'ភាសាហេព្រើរ',
        'hu-HU'=> 'ហុងគ្រី',
        'is-IS' => 'អ៊ីស្លង់',
        'id-ID'=> 'ឥណ្ឌូនេស៊ី',
        'ga-IE'=> 'អៀរឡង់',
        'it-IT'=> 'អ៊ីតាលី',
        'ja-JP'=> 'ជប៉ុន',
        'km-KH'=>'ខ្មែរ',
        'ko-KR'=> 'កូរ៉េ',
        'lt-LT'=>'លីទុយអានី',
        'lv-LV'=> 'ឡាតវី',
        'mk-MK'=> 'ម៉ាសេដូនៀ',
        'ms-MY'=> 'ម៉ាឡេ',
        'mi-NZ'=> 'ម៉ៅរី',
        'mn-MN'=> 'ម៉ុងហ្គោលី',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'ន័រវែស Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'ពែរ្ស',
        'pl-PL'=> 'ប៉ូឡូញ',
        'pt-PT'=> 'ព័រទុយហ្គាល់',
        'pt-BR'=> 'ព័រទុយហ្គាល់ ប្រេស៊ីល',
        'ro-RO'=> 'រ៉ូម៉ានី',
        'ru-RU'=> 'រុស្សី',
        'sr-CS' => 'ស៊ែប៊ី (ឡាតាំង)',
        'sk-SK'=> 'ស្លូវ៉ាគី',
        'sl-SI'=> 'ស្លូវេនី',
        'so-SO'=> 'សូម៉ាលី',
        'es-ES'=> 'ភាសាអេស្ប៉ាញ',
        'es-CO'=> 'អេស្ប៉ាញ កូឡុំប៊ី',
        'es-MX'=> 'អេស្ប៉ាញ ម៉ិកស៊ិក',
        'es-VE'=> 'អេស្ប៉ាញ វេណេស៊ុយអេឡា',
        'sv-SE'=> 'ស៊ុយអែត',
        'tl-PH'=> 'តាកាឡុក',
        'ta-IN'=> 'តាមីល',
        'th-TH'=> 'ថៃ',
        'tr-TR'=> 'ទួរគី',
        'uk-UA'=> 'អ៊ុយក្រែន',
        'vi-VN'=> 'វៀតណាម',
        'cy-GB'=> 'វែល',
        'zu-ZA'=> 'ហ្សូលូ',
    ],

    'select_country' => 'ជ្រើសរើសប្រទេសមួយ',
    
    'countries' => [
        'AC'=>'កោះ Ascension',
        'AD'=>'អង់ដូរ៉ា',
        'AE'=>'សហព័ន្ធ​អារ៉ាប់រួម',
        'AF'=>'អាហ្វហ្គានីស្ថាន',
        'AG'=>'Antigua និង Barbuda',
        'AI'=>'អង់ហ្គីឡា',
        'AL'=>'អាល់បានី',
        'AM'=>'អាមេនី',
        'AN'=>'ហូឡង់ Antilles',
        'AO'=>'អង់ហ្គោឡា',
        'AQ'=>'អង់តាក់ទិក',
        'AR'=>'អាហ្សង់ទីន',
        'AS'=>'សាម័រអាមេរិក',
        'AT'=>'អូទ្រីស',
        'AU'=>'អូស្ត្រាលី',
        'AW'=>'អារូបា',
        'AX'=>'Ãƒâ€¦land',
        'AZ'=>'អាស៊ែបៃហ្សង់',
        'BA'=>'បូស្នៀ និងហឺហ្សេហ្គោវីណា',
        'BB'=>'បាបាដូស',
        'BE'=>'បែលហ្សិក',
        'BD'=>'បង់ក្លាដែស',
        'BF'=>'ប៊ូគីណាហ្វាសូ',
        'BG'=>'ប៊ុលហ្គារី',
        'BH'=>'បារ៉ែន',
        'BI'=>'ប៊ូរុនឌី',
        'BJ'=>'បេនីន',
        'BM'=>'ប៊ឺមូដា',
        'BN'=>'ប្រទេស​ព្រុយ​ណេ​ដា​រូ​សា​ឡឹម',
        'BO'=>'បូលីវី',
        'BR'=>'ប្រេស៊ីល',
        'BS'=>'បាហាម៉ាស',
        'BT'=>'ប៊ូតាន',
        'BV'=>'កោះប៊ូវេ',
        'BW'=>'បូតស្វាណា',
        'BY'=>'បេឡារុស្ស',
        'BZ'=>'បេលីស',
        'CA'=>'ប្រទេសកាណាដា',
        'CC'=>'កោះ Cocos (Keeling)',
        'CD'=>'កុងហ្គោ (សាធារណរដ្ឋប្រជាធិបតេយ្យ)',
        'CF'=>'សាធារណរដ្ឋអាហ្វ្រិកកណ្តាល',
        'CG'=>'កុងហ្គោ (សាធារណរដ្ឋ)',
        'CH'=>'ប្រទេស​ស្វីស',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'កោះឃុក',
        'CL'=>'ឈីលី',
        'CM'=>'កេមេរូន',
        'CN'=>'សាធារណរដ្ឋប្រជាមានិតចិន',
        'CO'=>'កូឡុំប៊ី',
        'CR'=>'កូស្តារីកា',
        'CU'=>'គុយបា',
        'CV'=>'ខេបវឺដេ',
        'CX'=>'កោះគ្រីស្តម៉ាស',
        'CY'=>'សាធារណរដ្ឋស៊ីពរ៍',
        'CZ'=>'សាធារណរដ្ឋឆេក',
        'DE'=>'អាល្លឺម៉ង់',
        'DJ'=>'សាធារណរដ្ឋហ្ស៊ីបូទី',
        'DK'=>'ដាណឺម៉ាក',
        'DM'=>'ចក្រភពដូមីនីកា',
        'DO'=>'សាធារណរដ្ឋដូមីនីកែន',
        'DZ'=>'អាល់ហ្សេរី',
        'EC'=>'អេក្វាឌ័រ',
        'EE'=>'អេស្ដូនី',
        'EG'=>'អេហ្ស៊ីប',
        'GB-ENG'=>'ប្រទេសអង់គ្លេស',
        'ER'=>'អេរិទ្រីយ៉ា',
        'ES'=>'អេស្ប៉ាញ',
        'ET'=>'អេត្យូពី',
        'EU'=>'សហភាពអឺរ៉ុប',
        'FI'=>'ហ្វាំងឡង់',
        'FJ'=>'ហ្វីជី',
        'FK'=>'កោះហ្វ៉ក់ឡង់ (ម៉ាល់វី)',
        'FM'=>'មីក្រូណេស៊ី រដ្ឋសហព័ន្ធនៃ',
        'FO'=>'កោះហ្វារ៉ូ',
        'FR'=>'ប្រទេសបារាំង',
        'GA'=>'ហ្កាបុង',
        'GD'=>'ហ្រ្គេណាដា',
        'GE'=>'ហ្សកហ្ស៊ី',
        'GF'=>'ហ្វ្រង់ស្វ៊ីស',
        'GG'=>'ហ្គេនស៊ី',
        'GH'=>'ហ្គាណា',
        'GI'=>'ហ្គីលប្រាត័រ',
        'GL'=>'ហ្រ្គិនលែនដ៍',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Greece',
        'GS'=>'South Georgia And The South Sandwich Islands',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'ហុងកុង',
        'HM'=>'កោះ Heard និង Mcdonald',
        'HN'=>'ហុងឌូរ៉ាស',
        'HR'=>'ក្រូអាត (ឈ្មោះក្នុងស្រុក៖ Hrvatska)',
        'HT'=>'ហៃទី',
        'HU'=>'ហុងគ្រី',
        'ID'=>'ប្រទេសឥណ្ឌូនេស៊ី',
        'IE'=>'អៀរឡង់',
        'IL'=>'អ៊ីស្រាអែល',
        'IM'=>'កោះម៉ាន់',
        'IN'=>'ប្រទេសឥណ្ឌា',
        'IO'=>'ដែនដីមហាសមុទ្រឥណ្ឌាអង់គ្លេស',
        'IQ'=>'អ៊ីរ៉ាក់',
        'IR'=>'អ៊ីរ៉ង់ សាធារណរដ្ឋអ៊ីស្លាម',
        'IS'=>'អ៊ីស្លង់',
        'IT'=>'ប្រទេសអ៊ីតាលី',
        'JE'=>'ជឺស៊ី',
        'JM'=>'ចាម៉ៃកា',
        'JO'=>'ហ្ស៊កដានី',
        'JP'=>'ហ្ស៊កដានី',
        'KE'=>'កេនយ៉ា',
        'KG'=>'កៀហ្ស៊ីស៊ីស្ថាន',
        'KH'=>'កម្ពុជា',
        'KI'=>'គីរីបាទី',
        'KM'=>'កូម៉ូរ៉ូ',
        'KN'=>'Saint Kitts And Nevis',
        'KR'=>'កូរ៉េ សាធារណរដ្ឋ',
        'KW'=>'គុយវ៉ែត',
        'KY'=>'កោះកៃម៉ាន',
        'KZ'=>'កាហ្សាក់ស្ថាន',
        'LA'=>'សាធារណរដ្ឋប្រជាធិបតេយ្យប្រជាមានិតឡាវ',
        'LB'=>'លីបង់',
        'LC'=>'សាំងលូសៀ',
        'LI'=>'លីចតេនស្ទីន',
        'LK'=>'ស្រី​លង្កា',
        'LR'=>'លីបេរីយ៉ា',
        'LS'=>'ឡេសូតូ',
        'LT'=>'លីទុយអានី',
        'LU'=>'លុចសំបួរ',
        'LV'=>'ឡាតវី',
        'LY'=>'លីប៊ី អារ៉ាប់ ចាម៉ាហ៊ីរីយ៉ា',
        'MA'=>'ម៉ារ៉ុក',
        'MC'=>'ម៉ូណាកូ',
        'MD'=>'ម៉ុលដាវី សាធារណរដ្ឋ',
        'ME'=>'ម៉ុងតេណេហ្គ្រោ',
        'MG'=>'ម៉ាដាហ្គាស្ការ',
        'MH'=>'កោះម៉ាស្យែល',
        'MK'=>'ម៉ាសេដូនៀ អតីតសាធារណរដ្ឋយូហ្គោស្លាវី',
        'ML'=>'ប្រទេសម៉ាលី',
        'MM'=>'មីយ៉ាន់ម៉ា',
        'MN'=>'Mongolia',
        'MO'=>'Macau',
        'MP'=>'Northern Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolk Island',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Netherlands',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'French Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Philippines, Republic of the',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre And Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russian Federation',
        'RW'=>'Rwanda',
        'SA'=>'Saudi Arabia',
        'GB-SCT'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'សីស្ហែល',
        'SS'=>'South Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sweden',
        'SG'=>'Singapore',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard And Jan Mayen Islands',
        'SK'=>'Slovakia (Slovak Republic)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome And Principe',
        'SU'=>'Soviet Union',
        'SV'=>'El Salvador',
        'SY'=>'Syrian Arab Republic',
        'SZ'=>'Swaziland',
        'TC'=>'Turks And Caicos Islands',
        'TD'=>'Chad',
        'TF'=>'French Southern Territories',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'East Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (old code)',
        'TR'=>'Turkey',
        'TT'=>'Trinidad And Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, United Republic Of',
        'UA'=>'Ukraine',
        'UG'=>'Uganda',
        'UK'=>'United Kingdom',
        'US'=>'United States',
        'UM'=>'United States Minor Outlying Islands',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatican City State (Holy See)',
        'VC'=>'Saint Vincent And The Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Islands (British)',
        'VI'=>'Virgin Islands (U.S.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis And Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
